
FaradayIO Toolset Tutorials
======================================

Faraday IO is a basic Python toolset that can be used to interact with the RESTful API connecting the Faraday Digital Radio to a localhost server. The tutorials presented will walk from basic input/output operations to the process of building larger applications using the toolset.

Starting Proxy
--------------
All tutorials for FaradayIO require an active "Proxy" to be running. To start proxy simply double-click on the proxy.py script. You should see the python script running and server information present as you interact with it. To learn more about configuring and starting Faraday Proxy view the tutorial below.


Tutorials
---------

.. toctree::
	:caption: Tutorials
	:maxdepth: 1
	
	tutorial_proxy_config_init
	tutorial_faradayio_0
	tutorial_faradayio_1
	tutorial_faradayio_2
	tutorial_faradayio_3
	
